@@ -6,7 +6,7 @@ use JSON;
 use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::PSGI::Request;
 
-our $VERSION = '1.9.0';
+our $VERSION = '1.9.1';
 
 our $_json = JSON->new->allow_nonref;
 
@@ -102,7 +102,8 @@ sub sendJSONresponse {
     $args{headers} ||= [];
     my $type = 'application/json; charset=utf-8';
     if ( ref $j ) {
-        $j = $_json->encode($j);
+        eval { $j = $_json->encode($j); };
+        return $self->sendError( $req, $@ ) if ($@);
     }
     return [ $args{code}, [ 'Content-Type' => $type, @{ $args{headers} } ],
         [$j] ];
